@@ -56,6 +56,7 @@ def upload_function(global_config, zip_file):
         payload['organization'] = config.get('REPOSITORY','org')
         payload['provider'] = config.get('RUNTIME','provider')
         payload['runtime'] = config.get('RUNTIME','runtime')
+        payload['handler'] = config.get('RUNTIME','handler')
         payload['applicationToken'] = global_config.token
         with open(zip_file,'rb') as binfile:
             encoded = base64.b64encode(binfile.read())
@@ -66,7 +67,7 @@ def upload_function(global_config, zip_file):
         r = requests.post(
             global_config.endpoint,
             json=payload,
-            headers={'content-type':'application/json'}
+            headers={'content-type':'application/json', 'Authorization': global_config.token} if global_config.token else {'content-type':'application/json'}
         )
         click.echo(r.status_code)
 
